@@ -32,12 +32,22 @@ char *alloca ();
 #include <stdio.h>
 #include <builtin.h>
 #include <assert.h>
+#include <limits.h>
 #include "options.h"
 #include "read-line.h"
 #include "hash-table.h"
 #include "key-list.h"
 #include "trace.h"
 
+/* Make the hash table 8 times larger than the number of keyword entries. */
+static const int TABLE_MULTIPLE     = 10;
+
+/* Default type for generated code. */
+static char *const default_array_type  = "char *";
+
+/* in_word_set return type, by default. */
+static char *const default_return_type = "char *";
+
 /* Efficiently returns the least power of two greater than or equal to X! */
 #define POW(X) ((!X)?1:(X-=1,X|=X>>1,X|=X>>2,X|=X>>4,X|=X>>8,X|=X>>16,(++X)))
 
@@ -635,7 +645,7 @@ Key_List::output_keylength_table (void)
     {
       printf ("\n%sstatic %sunsigned %s lengthtable[] =\n%s%s{\n    ",
               indent, option[CONST] ? "const " : "",
-              max_key_len <= MAX_UNSIGNED_CHAR ? "char" : (max_key_len <= MAX_UNSIGNED_SHORT ? "short" : "long"),
+              max_key_len <= UCHAR_MAX ? "char" : (max_key_len <= USHRT_MAX ? "short" : "long"),
               indent, indent);
   
       for (temp = head; temp; temp = temp->next, index++)
@@ -750,7 +760,7 @@ Key_List::output_hash_function (void)
           ? "%s (register const char *str, register int len)\n{\n  static %sunsigned %s asso_values[] =\n    {"
           : "%s (str, len)\n     register char *str;\n     register int unsigned len;\n{\n  static %sunsigned %s asso_values[] =\n    {",
           option.get_hash_name (), option[CONST] ? "const " : "",
-          max_hash_value <= MAX_UNSIGNED_CHAR ? "char" : (max_hash_value <= MAX_UNSIGNED_SHORT ? "short" : "int"));
+          max_hash_value <= UCHAR_MAX ? "char" : (max_hash_value <= USHRT_MAX ? "short" : "int"));
   
   for (count = 0; count < ALPHA_SIZE; ++count)
     {
@@ -919,14 +929,14 @@ Key_List::output_lookup_array (void)
             }
         }
 
-      int max = MIN_INT;
+      int max = INT_MIN;
 
       for (lookup_ptr = lookup_array + max_hash_value + 1; lookup_ptr > lookup_array; max >?= abs (*--lookup_ptr))
         ;
 
       char *indent = option[GLOBAL] ? "" : "  ";
       printf ("%sstatic %s%s lookup[] =\n%s%s{\n      ", indent, option[CONST] ? "const " : "",
-              max <= MAX_SIGNED_CHAR ? "char" : (max <= MAX_SIGNED_SHORT ? "short" : "int"),
+              max <= SCHAR_MAX ? "char" : (max <= USHRT_MAX ? "short" : "int"),
               indent, indent);
 
       int count = max;
@@ -1133,8 +1143,8 @@ Key_List::Key_List (void)
 {   
   T (Trace t ("Key_List::Key_List");)
   total_keys       = 1;
-  max_key_len      = MIN_INT;
-  min_key_len      = MAX_INT;
+  max_key_len      = INT_MIN;
+  min_key_len      = INT_MAX;
   return_type      = default_return_type;
   array_type       = struct_tag  = default_array_type;
   head             = 0;
